@@ -1,17 +1,20 @@
 # -*- coding: utf-8 -*-
 import re
 from django import template
-from django.template.defaultfilters import removetags
+from django.template.defaultfilters import striptags, removetags
 import settings
 
 
 register = template.Library()
 url_regex = re.compile(r"((^|\b)www\.([-A-Za-z0-9+&@#/%?=~_()|!:,.;]*[-A-Za-z0-9+&@#/%=~_()|]))")
+all_regex = re.compile(r"\S")
 block_char = u'▉'
 
 
 def is_censored(value):
     """Returns True or False if value contains links."""
+    if settings.SOPA_REPLACE_MODE == 'ALL':
+        return True
     if url_regex.search(value):
         return True
     return False
@@ -30,9 +33,19 @@ def censor(value, replace=None):
 
     The special value 'BLOCKS' will replace every char in the link with a black square.
     """
-    value = removetags(value, 'a')
-    if replace is None:
-        replace = settings.SOPA_REPLACE
-    if replace == 'BLOCKS':
-        return url_regex.sub(repl_blocks, value)
-    return url_regex.sub(replace, value)
+    if settings.SOPA_REPLACE_MODE == 'ALL':
+        value = striptags(value)
+        if replace is None:
+            replace = settings.SOPA_REPLACE
+        if replace == 'BLOCKS':
+            return all_regex.sub(repl_blocks, value)
+        else:
+            return replace
+
+    if settings.SOPA_REPLACE_MODE == 'LINKS':
+        value = removetags(value, 'a')
+        if replace is None:
+            replace = settings.SOPA_REPLACE
+        if replace == 'BLOCKS':
+            replace = repl_blocks
+        return url_regex.sub(replace, value)
