@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from templatetags.sopa import is_censored, censor
+import settings
 import unittest2
 
 
@@ -27,5 +28,14 @@ class SOPATest(unittest2.TestCase):
         result = censor(self.text2, '<em>redacted</em>')
         self.assertEqual(result, self.text2)
 
+        settings.SOPA_REPLACE_MODE = 'ALL'
+        result = censor(self.text)
+        self.assertEqual(result, u'▉▉▉▉▉ ▉▉▉▉▉ ▉▉▉▉▉▉▉▉▉▉▉▉▉▉ ▉▉▉ ▉▉▉▉')
+
+        settings.SOPA_REPLACE = '<redacted>'
+        result = censor(self.text)
+        self.assertEqual(result, u'<redacted>')
+
+
 if __name__ == '__main__':
     unittest2.main()
